gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] 02/06: more clear naming of variables


From: gnunet
Subject: [taler-exchange] 02/06: more clear naming of variables
Date: Sun, 04 Aug 2024 12:54:15 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

commit 976589d69bb836957148506a35996f97640962a0
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Sun Aug 4 12:51:53 2024 +0200

    more clear naming of variables
---
 src/include/taler_kyclogic_lib.h | 4 ++--
 src/kyclogic/Makefile.am         | 1 +
 src/kyclogic/kyclogic_api.c      | 8 ++++----
 3 files changed, 7 insertions(+), 6 deletions(-)

diff --git a/src/kyclogic/Makefile.am b/src/kyclogic/Makefile.am
index bf258b278..7da1f758f 100644
--- a/src/kyclogic/Makefile.am
+++ b/src/kyclogic/Makefile.am
@@ -16,6 +16,7 @@ pkgcfg_DATA = \
 
 bin_SCRIPTS = \
   taler-exchange-helper-converter-oauth2-test-full_name \
+  taler-exchange-helper-measure-test-form \
   taler-exchange-helper-measure-test-oauth \
   taler-exchange-kyc-kycaid-converter.sh \
   taler-exchange-kyc-persona-converter.sh \
diff --git a/src/kyclogic/kyclogic_api.c b/src/kyclogic/kyclogic_api.c
index 4bad55f68..0930371c6 100644
--- a/src/kyclogic/kyclogic_api.c
+++ b/src/kyclogic/kyclogic_api.c
@@ -2751,7 +2751,7 @@ TALER_KYCLOGIC_measure_to_requirement (
   const char *prog_name,
   const struct TALER_AccountAccessTokenP *access_token,
   size_t offset,
-  uint64_t row_id)
+  uint64_t legitimization_measure_row_id)
 {
   struct TALER_KYCLOGIC_KycCheck *kc;
   json_t *kri;
@@ -2767,7 +2767,7 @@ TALER_KYCLOGIC_measure_to_requirement (
   }
   GNUNET_assert (offset <= UINT32_MAX);
   TALER_kyc_measure_authorization_hash (access_token,
-                                        row_id,
+                                        legitimization_measure_row_id,
                                         (uint32_t) offset,
                                         &shv);
   switch (kc->type)
@@ -2788,7 +2788,7 @@ TALER_KYCLOGIC_measure_to_requirement (
                      "%s-%u-%llu",
                      ids,
                      (unsigned int) offset,
-                     (unsigned long long) row_id);
+                     (unsigned long long) legitimization_measure_row_id);
     GNUNET_free (ids);
     kri = GNUNET_JSON_PACK (
       GNUNET_JSON_pack_string ("form",
@@ -2809,7 +2809,7 @@ TALER_KYCLOGIC_measure_to_requirement (
                      "%s-%u-%llu",
                      ids,
                      (unsigned int) offset,
-                     (unsigned long long) row_id);
+                     (unsigned long long) legitimization_measure_row_id);
     GNUNET_free (ids);
     kri = GNUNET_JSON_PACK (
       GNUNET_JSON_pack_string ("form",

diff --git a/src/include/taler_kyclogic_lib.h b/src/include/taler_kyclogic_lib.h
index 7f7b27169..1fcf65ace 100644
--- a/src/include/taler_kyclogic_lib.h
+++ b/src/include/taler_kyclogic_lib.h
@@ -521,7 +521,7 @@ TALER_KYCLOGIC_check_form (
  * @param prog_name the program to run
  * @param access_token access token for the measure
  * @param offset offset of the measure
  * @param row_id row in the legitimization_measures table
table
  * @return JSON object with matching KycRequirementInformation
  */
 json_t *
@@ -530,7 +530,7 @@ TALER_KYCLOGIC_measure_to_requirement (
   const char *prog_name,
   const struct TALER_AccountAccessTokenP *access_token,
   size_t offset,
-  uint64_t row_id);
+  uint64_t legitimization_measure_row_id);
 
 
 /**
@@ -521,7 +521,7 @@ TALER_KYCLOGIC_check_form (
  * @param access_token access token for the measure
  * @param offset offset of the measure
- * @param row_id row in the legitimization_measures table
+ * @param legitimization_measure_row_id row in the legitimization_measures 
table
  * @return JSON object with matching KycRequirementInformation
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]